<?php

namespace Drupal\video_toolbox\Traits;

use Drupal\Core\Session\AccountInterface;
use Drupal\video_toolbox\VideoHandlerInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a trait for the depency injection for forms.
 */
trait VideoFormDependencyInjectionTrait {

  /**
   * Account Service.
   *
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected $account;

  /**
   * Video Handler Service.
   *
   * @var \Drupal\video_toolbox\VideoHandlerInterface
   */
  protected $videoHandler;

  /**
   * The storage handler class for files.
   *
   * @var \Drupal\file\FileStorage
   */
  protected $fileStorage;

  /**
   * Constructor to initialize Services.
   *
   * @param \Drupal\Core\Session\AccountInterface $account
   *   The Account Service for user information.
   * @param \Drupal\video_toolbox\VideoHandlerInterface $videoHandler
   *   The Video Handler Service.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The Entity Manager Service, used for File entities.
   */
  public function __construct(
    AccountInterface $account,
    VideoHandlerInterface $videoHandler,
    EntityTypeManagerInterface $entity_type_manager
  ) {
    $this->account = $account;
    $this->videoHandler = $videoHandler;
    $this->fileStorage = $entity_type_manager->getStorage('file');
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    // Instantiates this form class.
    return new static(
      // Load the service required to construct this class.
      $container->get('current_user'),
      $container->get('video.get_service'),
      $container->get('entity_type.manager'),
    );
  }

}
